@@ -1,4 +1,4 @@
-/* Copyright (C) 2016-2022 Greenbone Networks GmbH
+/* Copyright (C) 2016-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -114,6 +114,8 @@ export class UserCommand extends EntityCommand {
           forEach(group.auth_conf_setting, setting => {
             if (setting.key === 'enable') {
               values.enabled = setting.value === true;
+            } else if (setting.key === 'ldaps-only') {
+              values.ldapsOnly = setting.value === true;
             } else {
               values[setting.key] = setting.value;
             }
