@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2022 Greenbone Networks GmbH
+/* Copyright (C) 2017-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -127,8 +127,10 @@ class Host {
         }
         if (name.startsWith('Auth')) {
           const authArray = name.split('-');
-          copy.authSuccess[authArray[1].toLowerCase()] =
-            authArray[2] === 'Success';
+          if (copy.authSuccess[authArray[1].toLowerCase()] !== true) {
+            copy.authSuccess[authArray[1].toLowerCase()] =
+              authArray[2] === 'Success';
+          }
         }
         copy.details.appsCount = appsCount;
       });
