@@ -16,9 +16,22 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 import Model from 'gmp/model';
+import {isDefined} from 'gmp/utils/identity';
+import {parseDate} from 'gmp/parser';
 
 class Vulnerability extends Model {
   static entityType = 'vulnerability';
+
+  static parseElement(element) {
+    const ret = super.parseElement(element);
+
+    if (isDefined(ret.results)) {
+      ret.results.newest = parseDate(ret.results.newest);
+      ret.results.oldest = parseDate(ret.results.newest);
+    }
+
+    return ret;
+  }
 }
 
 export default Vulnerability;
