@@ -27,6 +27,8 @@ import {isDefined} from 'gmp/utils/identity';
 
 import App from './web/app.js';
 
+import {StyleSheetManager} from 'styled-components';
+
 const config = isDefined(global.config) ? global.config : {};
 const {sentryDSN, sentryEnvironment} = config;
 
@@ -38,6 +40,11 @@ Sentry.init({
   release: GSA_VERSION,
 });
 
-ReactDOM.render(<App />, document.getElementById('app'));
+ReactDOM.render(
+  <StyleSheetManager enableVendorPrefixes>
+    <App />
+  </StyleSheetManager>,
+  document.getElementById('app'),
+);
 
 // vim: set ts=2 sw=2 tw=80:
