@@ -24,8 +24,9 @@ import {isDefined, hasValue} from 'gmp/utils/identity';
 
 import PropTypes from 'web/utils/proptypes';
 import Theme from 'web/utils/theme';
+import {styledExcludeProps} from 'web/utils/styledConfig';
 
-const BadgeContainer = styled.div`
+const BadgeContainer = styledExcludeProps(styled.div, ['margin'])`
   position: relative;
   display: inline-flex;
   margin-right: ${props => props.margin}px;
@@ -33,7 +34,10 @@ const BadgeContainer = styled.div`
 
 BadgeContainer.displayName = 'BadgeContainer';
 
-const BadgeIcon = styled.span`
+const BadgeIcon = styledExcludeProps(styled.span, [
+  'backgroundColor',
+  'margin',
+])`
   display: flex;
   flex-direction: row;
   flex-wrap: wrap;
