@@ -21,6 +21,7 @@ import {isFunction} from 'gmp/utils/identity';
 
 import {render} from 'web/utils/testing';
 import Theme from 'web/utils/theme';
+import PropTypes from 'web/utils/proptypes';
 
 import {
   Box,
@@ -207,20 +208,54 @@ class MenuTestComponent extends React.Component {
     super(...args);
 
     this.target = React.createRef();
+    const {mockBoundingClientRect, ...otherProps} = this.props;
+    this.mockBoundingClientRect = mockBoundingClientRect;
+    this.otherProps = otherProps;
+    this.notifyRefAssigned = jest.fn();
   }
 
   render() {
     const hasTarget = this.target.current !== null;
+    if (hasTarget && this.mockBoundingClientRect) {
+      const rect = this.target.current.closest('.multiselect-scroll');
+      if (rect !== null) {
+        jest.spyOn(rect, 'getBoundingClientRect').mockImplementation(() => {
+          return {
+            top: 100,
+            bottom: 50,
+            height: 20,
+            width: 100,
+            right: 10,
+            left: 50,
+          };
+        });
+      }
+    }
     return (
       <div>
-        <div ref={this.target} style={{width: '200px', height: '100px'}} />
-        {hasTarget && <Menu {...this.props} target={this.target} />}
+        <div
+          ref={this.target}
+          className={this.mockBoundingClientRect ? 'multiselect-scroll' : ''}
+          style={{width: '200px', height: '100px'}}
+        />
+        {hasTarget && (
+          <Menu
+            {...this.otherProps}
+            notifyRefAssigned={this.notifyRefAssigned}
+            target={this.target}
+          />
+        )}
       </div>
     );
   }
 }
 
+MenuTestComponent.propTypes = {
+  mockBoundingClientRect: PropTypes.bool,
+};
+
 describe('Menu tests', () => {
+  window.innerHeight = 180;
   const renderTest = props => {
     const {rerender, ...other} = render(<MenuTestComponent {...props} />);
     rerender(<MenuTestComponent {...props} />);
@@ -229,9 +264,14 @@ describe('Menu tests', () => {
 
   test('should render', () => {
     const {getByTestId} = renderTest();
-
     const menu = getByTestId('select-menu');
+    expect(menu).toMatchSnapshot();
+  });
 
+  test('should render with position reference to parent element', () => {
+    const {getByTestId} = renderTest({mockBoundingClientRect: true});
+    const menu = getByTestId('select-menu');
+    expect(menu).toHaveStyleRule({top: '120px'});
     expect(menu).toMatchSnapshot();
   });
 
@@ -252,12 +292,33 @@ describe('Menu tests', () => {
   });
 
   test('should not render without target', () => {
-    const {queryByTestId} = render(<Menu target={null} />);
+    const notifyRefAssigned = jest.fn();
+    const {queryByTestId} = render(
+      <Menu target={null} notifyRefAssigned={notifyRefAssigned} />,
+    );
 
     const menu = queryByTestId('select-menu');
 
     expect(menu).toBeNull();
   });
+
+  test('should render with open direction upwards', () => {
+    const {getByTestId} = renderTest({
+      mockBoundingClientRect: true,
+      menuHeight: 75,
+    });
+    const menu = getByTestId('select-menu');
+    expect(menu).toMatchSnapshot();
+  });
+
+  test('should render with open direction downwards', () => {
+    const {getByTestId} = renderTest({
+      mockBoundingClientRect: true,
+      menuHeight: 55,
+    });
+    const menu = getByTestId('select-menu');
+    expect(menu).toMatchSnapshot();
+  });
 });
 
 // vim: set ts=2 sw=2 tw=80:
