@@ -25,6 +25,7 @@ import {parseInt} from 'gmp/parser';
 
 import Layout from 'web/components/layout/layout';
 import PropTypes from 'web/utils/proptypes';
+import {styledExcludeProps} from 'web/utils/styledConfig';
 
 const COLUMNS = [
   '0',
@@ -49,7 +50,7 @@ const FormGroupLayout = styled.div`
   padding-bottom: 10px;
 `;
 
-const Title = styled.label`
+const Title = styledExcludeProps(styled.label, ['titleSize', 'titleOffset'])`
   display: inline-block;
   max-width: 100%;
   font-weight: bold;
@@ -60,7 +61,7 @@ const Title = styled.label`
   margin-left: ${props => COLUMNS[props.titleOffset]};
 `;
 
-const FormGroupContent = styled(Layout)`
+const FormGroupContent = styledExcludeProps(styled(Layout), ['size', 'offset'])`
   ${props => {
     const ret = {};
     if (isDefined(props.size)) {
