@@ -24,10 +24,11 @@ import {isDefined, hasValue} from 'gmp/utils/identity';
 
 import Theme from 'web/utils/theme';
 import PropTypes from 'web/utils/proptypes';
+import {styledExcludeProps} from 'web/utils/styledConfig';
 
 import Portal from 'web/components/portal/portal';
 
-export const Box = styled.div`
+export const Box = styledExcludeProps(styled.div, ['hasError', 'isOpen'])`
   border: 1px solid ${Theme.inputBorderGray};
   border-radius: 2px;
   display: flex;
@@ -59,7 +60,7 @@ export const Input = styled.input`
   line-height: inherit;
 `;
 
-export const Item = styled.span`
+export const Item = styledExcludeProps(styled.span, ['isActive', 'isSelected'])`
   padding: 1px 5px;
   cursor: pointer;
   &:hover {
@@ -84,7 +85,7 @@ export const ItemContainer = styled.div`
   flex-direction: column;
 `;
 
-const MenuContainer = styled.div`
+const MenuContainer = styledExcludeProps(styled.div, ['position'])`
   outline: 0;
   border-radius: 0 0 4px 4px;
   transition: opacity 0.1s ease;
@@ -184,6 +185,7 @@ class MenuComponent extends React.Component {
     if (this.eventTarget !== window) {
       window.addEventListener('scroll', this.handleScroll, {passive: true});
     }
+    this.props.notifyRefAssigned();
   }
 
   componentWillUnmount() {
@@ -195,15 +197,21 @@ class MenuComponent extends React.Component {
   }
 
   render() {
-    const {target, forwardedRef, ...props} = this.props;
+    const {target, forwardedRef, menuHeight, notifyRefAssigned, ...props} =
+      this.props;
 
     if (!hasValue(target) || target.current === null) {
       return null;
     }
 
-    const rect = target.current.getBoundingClientRect();
+    const rect = hasValue(target.current.closest('.multiselect-scroll'))
+      ? target.current.closest('.multiselect-scroll').getBoundingClientRect()
+      : target.current.getBoundingClientRect();
+
     const {height, width, right, left, top} = rect;
 
+    const y = top + getScrollY() + height;
+
     return (
       <Portal>
         <MenuContainer
@@ -213,7 +221,11 @@ class MenuComponent extends React.Component {
           right={document.body.clientWidth - right}
           width={width}
           x={left + getScrollX()}
-          y={top + getScrollY() + height}
+          y={
+            hasValue(menuHeight) && window.innerHeight - y < menuHeight
+              ? top + getScrollY() - menuHeight
+              : y
+          }
         />
       </Portal>
     );
@@ -222,6 +234,8 @@ class MenuComponent extends React.Component {
 
 MenuComponent.propTypes = {
   forwardedRef: PropTypes.ref,
+  menuHeight: PropTypes.number,
+  notifyRefAssigned: PropTypes.func,
   target: PropTypes.ref,
 };
 
