@@ -22,8 +22,13 @@ import {isDefined} from 'gmp/utils/identity';
 import PropTypes from 'web/utils/proptypes';
 
 import Divider from './divider';
+import {styledExcludeProps} from 'web/utils/styledConfig';
 
-const HorizontalSep = styled(Divider)`
+const HorizontalSep = styledExcludeProps(styled(Divider), [
+  'separator',
+  'spacing',
+  'wrap',
+])`
   flex-wrap: ${props => (isDefined(props.wrap) ? props.wrap : null)};
   & > *:not(:last-child)::after {
     content: ${({separator = '•'}) => `'${separator}'`};
