@@ -24,6 +24,7 @@ import {isDefined} from 'gmp/utils/identity';
 
 import DeleteIcon from 'web/components/icon/deleteicon';
 
+import {styledExcludeProps} from 'web/utils/styledConfig';
 import PropTypes from 'web/utils/proptypes';
 
 import Theme from 'web/utils/theme';
@@ -32,14 +33,14 @@ import Layout from 'web/components/layout/layout';
 
 import Button from './button';
 
-const Panel = styled(Layout)`
+const Panel = styledExcludeProps(styled(Layout), ['isWarning', 'noMargin'])`
   background-color: ${Theme.white};
   border: 1px solid
     ${props => (props.isWarning ? Theme.darkRed : Theme.lightBlue)};
   margin-top: ${props => (props.noMargin ? '0px' : '5px')};
 `;
 
-const Heading = styled.div`
+const Heading = styledExcludeProps(styled.div, ['isWarning'])`
   display: flex;
   justify-content: space-between;
   align-items: center;
