@@ -22,6 +22,7 @@ import styled from 'styled-components';
 import {Draggable} from 'react-beautiful-dnd';
 
 import PropTypes from 'web/utils/proptypes';
+import {styledExcludeProps} from 'web/utils/styledConfig';
 
 export const GRID_ITEM_MARGIN = {
   top: 5,
@@ -30,7 +31,7 @@ export const GRID_ITEM_MARGIN = {
   right: 8,
 };
 
-const GridItem = styled.div`
+const GridItem = styledExcludeProps(styled.div, ['isDragging'])`
   display: flex;
   flex-grow: 1;
   flex-shrink: 1;
