@@ -23,8 +23,9 @@ import styled from 'styled-components';
 import Theme from 'web/utils/theme.js';
 
 import PropTypes from 'web/utils/proptypes.js';
+import {styledExcludeProps} from 'web/utils/styledConfig';
 
-const StyledDiv = styled.div`
+const StyledDiv = styledExcludeProps(styled.div, ['active'])`
   font-size: 16px;
   display: flex;
   align-items: start;
@@ -46,11 +47,13 @@ const StyledDiv = styled.div`
   margin-bottom: ${props => (props.active ? '-2px' : undefined)};
   border-top: ${props =>
     props.active ? '2px solid ' + Theme.green : '2px solid ' + Theme.white};
-  :hover {
+  &:hover {
     border-top: ${props =>
-      props.active ? undefined : '2px solid ' + Theme.lightGray};
+      props.active
+        ? '2px solid ' + Theme.green
+        : '2px solid ' + Theme.lightGray};
   }
-  :first-child {
+  &:first-child {
     border-left: ${props =>
       props.active
         ? '1px solid ' + Theme.lightGray
