@@ -24,7 +24,7 @@ import Layout from '../layout/layout.js';
 
 const TabList = ({active = 0, children, onActivateTab, ...props}) => {
   children = React.Children.map(children, (child, index) => {
-    if (child !== null) {
+    if (child !== null && child.type !== Layout) {
       return React.cloneElement(child, {
         isActive: active === index,
         onActivate: () => onActivateTab(index),
