@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2022 Greenbone Networks GmbH
+/* Copyright (C) 2017-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -31,6 +31,8 @@ import {
   CONDITION_DIRECTION_INCREASED,
 } from 'gmp/models/alert';
 
+import PropTypes from 'web/utils/proptypes';
+
 const Condition = ({condition = {}, event}) => {
   if (!isDefined(condition.type) || !isDefined(condition.data)) {
     return null;
@@ -98,6 +100,11 @@ const Condition = ({condition = {}, event}) => {
   return condition.type;
 };
 
+Condition.propTypes = {
+  condition: PropTypes.object,
+  event: PropTypes.object.isRequired,
+};
+
 export default Condition;
 
 // vim: set ts=2 sw=2 tw=80:
