@@ -302,6 +302,7 @@ class AlertDialog extends React.Component {
       title = _('New Alert'),
       report_formats,
       report_format_ids,
+      method_data_composer_ignore_pagination,
       method_data_composer_include_notes,
       method_data_composer_include_overrides,
       method_data_recipient_credential,
@@ -484,6 +485,7 @@ class AlertDialog extends React.Component {
       event,
       filter_id,
       method_data_pkcs12_credential,
+      method_data_composer_ignore_pagination,
       method_data_composer_include_notes,
       method_data_composer_include_overrides,
       method_data_recipient_credential,
@@ -888,6 +890,7 @@ AlertDialog.propTypes = {
   filter_id: PropTypes.idOrZero,
   method: PropTypes.string,
   method_data_URL: PropTypes.string,
+  method_data_composer_ignore_pagination: PropTypes.number,
   method_data_composer_include_notes: PropTypes.number,
   method_data_composer_include_overrides: PropTypes.number,
   method_data_defense_center_ip: PropTypes.string,
