@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2022 Greenbone Networks GmbH
+/* Copyright (C) 2017-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -41,9 +41,10 @@ import {
 } from 'gmp/models/alert';
 
 import PropTypes from 'web/utils/proptypes';
-
 import HorizontalSep from 'web/components/layout/horizontalsep';
 
+import CertInfo from 'web/components/certinfo/certinfo';
+
 import DetailsLink from 'web/components/link/detailslink';
 
 import SimpleTable from 'web/components/table/simpletable';
@@ -197,6 +198,13 @@ const Method = ({method = {}, details = false, reportFormats = []}) => {
                 </TableRow>
               )}
 
+              {isDefined(data.scp_port?.value) && (
+                <TableRow>
+                  <TableData>{_('Port')}</TableData>
+                  <TableData>{data.scp_port.value}</TableData>
+                </TableRow>
+              )}
+
               {isDefined(credential) && isDefined(credential.id) && (
                 <TableRow>
                   <TableData>{_('Credential')}</TableData>
@@ -309,6 +317,12 @@ const Method = ({method = {}, details = false, reportFormats = []}) => {
                   </TableData>
                 </TableRow>
               )}
+              {isDefined(data.smb_max_protocol?.value) && (
+                <TableRow>
+                  <TableData>{_('Max Protocol')}</TableData>
+                  <TableData>{data.smb_max_protocol.value}</TableData>
+                </TableRow>
+              )}
             </TableBody>
           </Table>
         </div>
@@ -619,7 +633,25 @@ const Method = ({method = {}, details = false, reportFormats = []}) => {
                     {_('Use workaround for default certificate')}
                   </TableData>
                   <TableData>
-                    {data.tp_sms_tls_workaround.value === '1' ? 'Yes' : 'No'}
+                    {data.tp_sms_tls_workaround.value === 1 ? 'Yes' : 'No'}
+                  </TableData>
+                </TableRow>
+              )}
+              {isDefined(data.tp_sms_tls_certificate?.value) && (
+                <TableRow>
+                  <TableData>{_('TLS Certificate')}</TableData>
+                  <TableData>
+                    {isDefined(
+                      data.tp_sms_tls_certificate?.certificate_info,
+                    ) ? (
+                      <CertInfo
+                        info={data.tp_sms_tls_certificate.certificate_info}
+                      />
+                    ) : (
+                      _(
+                        'No information available for existing file. File may not be a correct certificate.',
+                      )
+                    )}
                   </TableData>
                 </TableRow>
               )}
