@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2022 Greenbone Networks GmbH
+/* Copyright (C) 2017-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -18,6 +18,7 @@
 import React from 'react';
 
 import _ from 'gmp/locale';
+import {_l} from 'gmp/locale/lang';
 
 import {
   SMB_CREDENTIAL_TYPES,
@@ -38,12 +39,20 @@ import TextField from 'web/components/form/textfield';
 
 import NewIcon from 'web/components/icon/newicon';
 
+const smbMaxProtocolItems = [
+  {label: _l('Default'), value: ''},
+  {label: 'NT1', value: 'NT1'},
+  {label: 'SMB2', value: 'SMB2'},
+  {label: 'SMB3', value: 'SMB3'},
+];
+
 const SmbMethodPart = ({
   prefix,
   credentials = [],
   reportFormats,
   smbCredential,
   smbFilePath,
+  smbMaxProtocol,
   smbReportFormat,
   smbSharePath,
   onChange,
@@ -108,6 +117,15 @@ const SmbMethodPart = ({
           onChange={onChange}
         />
       </FormGroup>
+
+      <FormGroup title={_('Max Protocol')}>
+        <Select
+          name={prefix + 'smb_max_protocol'}
+          items={smbMaxProtocolItems}
+          value={smbMaxProtocol}
+          onChange={onChange}
+        />
+      </FormGroup>
     </Layout>
   );
 };
@@ -118,6 +136,7 @@ SmbMethodPart.propTypes = {
   reportFormats: PropTypes.array,
   smbCredential: PropTypes.id,
   smbFilePath: PropTypes.string.isRequired,
+  smbMaxProtocol: PropTypes.string,
   smbReportFormat: PropTypes.id,
   smbSharePath: PropTypes.string.isRequired,
   onChange: PropTypes.func.isRequired,
