@@ -229,9 +229,9 @@ describe('NvtsPage tests', () => {
         get: getNvts,
         deleteByFilter,
         exportByFilter,
-        getActiveDaysAggregates: getAggregates,
+        getSeverityAggregates: getAggregates,
+        getFamilyAggregates: getAggregates,
         getCreatedAggregates: getAggregates,
-        getWordCountsAggregates: getAggregates,
       },
       filters: {
         get: getFilters,
@@ -301,9 +301,9 @@ describe('NvtsPage tests', () => {
         get: getNvts,
         delete: deleteByIds,
         export: exportByIds,
-        getActiveDaysAggregates: getAggregates,
+        getSeverityAggregates: getAggregates,
+        getFamilyAggregates: getAggregates,
         getCreatedAggregates: getAggregates,
-        getWordCountsAggregates: getAggregates,
       },
       filters: {
         get: getFilters,
@@ -388,9 +388,9 @@ describe('NvtsPage tests', () => {
         get: getNvts,
         deleteByFilter,
         exportByFilter,
-        getActiveDaysAggregates: getAggregates,
+        getSeverityAggregates: getAggregates,
+        getFamilyAggregates: getAggregates,
         getCreatedAggregates: getAggregates,
-        getWordCountsAggregates: getAggregates,
       },
       filters: {
         get: getFilters,
