@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2022 Greenbone Networks GmbH
+/* Copyright (C) 2017-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -40,9 +40,13 @@ const SORT_FIELDS = [
     name: 'average_severity',
     displayName: _l('Severity: Average'),
   },
+  {
+    name: 'all_hosts',
+    displayName: _l('Hosts (All)'),
+  },
   {
     name: 'hosts',
-    displayName: _l('Hosts'),
+    displayName: _l('Hosts (Best OS)'),
   },
   {
     name: 'modified',
