@@ -51,12 +51,23 @@ import PropTypes from 'web/utils/proptypes';
 import Trend from './trend';
 
 const WHOLE_SELECTION_FAMILIES = [
+  'AIX Local Security Checks',
+  'AlmaLinux Security Checks',
+  'Amazon Linux Security Checks',
   'CentOS Local Security Checks',
   'Debian Local Security Checks',
   'Fedora Local Security Checks',
+  'FreeBSD Local Security Checks',
+  'Gentoo Local Security Checks',
+  'HP-UX Local Security Checks',
   'Huawei EulerOS Local Security Checks',
+  'Mageia Linux Local Security Checks',
+  'Mandrake Local Security Checks',
   'Oracle Linux Local Security Checks',
   'Red Hat Local Security Checks',
+  'Rocky Linux Local Security Checks',
+  'Slackware Local Security Checks',
+  'Solaris Local Security Checks',
   'SuSE Local Security Checks',
   'Ubuntu Local Security Checks',
 ];
