@@ -20,6 +20,7 @@ import React from 'react';
 import _ from 'gmp/locale';
 
 import PropTypes from 'web/utils/proptypes';
+import {isDefined} from 'gmp/utils/identity';
 import {capitalizeFirstLetter} from 'gmp/utils/string';
 import withCapabilities from 'web/utils/withCapabilities';
 
@@ -47,6 +48,24 @@ const TaskStartIcon = ({
     );
   }
 
+  if (
+    isDefined(task.schedule) &&
+    task.schedule?.event?.event?.duration?.toSeconds() > 0
+  ) {
+    return (
+      <StartIcon
+        active={false}
+        title={_(
+          '{{usageType}} cannot be started manually' +
+            ' because the assigned schedule has a duration limit',
+          {
+            usageType: capitalizeFirstLetter(usageType),
+          },
+        )}
+      />
+    );
+  }
+
   if (!task.isActive()) {
     return <StartIcon title={_('Start')} value={task} onClick={onClick} />;
   }
