@@ -1,4 +1,4 @@
-/* Copyright (C) 2019-2022 Greenbone Networks GmbH
+/* Copyright (C) 2019-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -21,7 +21,11 @@ import {createFilterDialog} from '../../components/powerfilter/dialog.js';
 
 const SORT_FIELDS = [
   {
-    name: 'name',
+    name: 'subject_dn',
+    displayName: _l('Subject DN'),
+  },
+  {
+    name: 'issuer_dn',
     displayName: _l('Issuer DN'),
   },
   {
