@@ -1,4 +1,4 @@
-/* Copyright (C) 2019-2022 Greenbone Networks GmbH
+/* Copyright (C) 2019-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -46,9 +46,9 @@ const Header = ({
           width="30%"
           currentSortDir={currentSortDir}
           currentSortBy={currentSortBy}
-          sortBy={sort ? 'issuer_dn' : false}
+          sortBy={sort ? 'subject_dn' : false}
           onSortChange={onSortChange}
-          title={_('Issuer DN')}
+          title={_('Subject DN')}
         />
         <TableHead
           width="26%"
