@@ -329,6 +329,7 @@ class UserSettings extends React.Component {
       certBundFilter,
       dfnCertFilter,
       autoCacheRebuild = {},
+      deltaReportsVersion,
     } = this.props;
 
     alertsFilter = hasValue(alertsFilter) ? alertsFilter : {};
@@ -455,6 +456,12 @@ class UserSettings extends React.Component {
                               : ''}
                           </TableData>
                         </TableRow>
+                        <TableRow>
+                          <TableData>
+                            {_('Delta Reports Version (immutable)')}
+                          </TableData>
+                          <TableData>{deltaReportsVersion}</TableData>
+                        </TableRow>
                       </TableBody>
                     </Table>
                   </TabPanel>
@@ -808,7 +815,8 @@ UserSettings.propTypes = {
   defaultSnmpCredential: PropTypes.object,
   defaultSshCredential: PropTypes.object,
   defaultTarget: PropTypes.object,
-  detailsExportFileName: PropTypes.object,
+  deltaReportsVersion: PropTypes.string,
+  detailsExportFileName: PropTypes.string,
   dfnCertFilter: PropTypes.object,
   dynamicSeverity: PropTypes.object,
   filters: PropTypes.array,
@@ -971,6 +979,9 @@ const mapStateToProps = rootState => {
   const certBundFilter = userDefaultFilterSelector.getFilter('certbund');
   const dfnCertFilter = userDefaultFilterSelector.getFilter('dfncert');
   const nvtFilter = userDefaultFilterSelector.getFilter('nvt');
+  const deltaReportsVersion = userDefaultsSelector.getValueByName(
+    'deltareportsversion',
+  );
 
   let scanconfigs = scanConfigsSel.getEntities(ALL_FILTER);
   if (isDefined(scanconfigs)) {
@@ -1036,6 +1047,7 @@ const mapStateToProps = rootState => {
     dfnCertFilter,
     nvtFilter,
     autoCacheRebuild,
+    deltaReportsVersion,
   };
 };
 
