@@ -56,18 +56,15 @@ export const mayRequire = validator => {
   return wrapper;
 };
 
-export const deprecated = (validator, message = '') => (
-  props,
-  prop_name,
-  component_name,
-  ...rest
-) => {
-  warning(
-    isDefined(props[prop_name]),
-    `'${prop_name}' is deprecated on ${component_name}. ${message}`,
-  );
-  return validator(props, prop_name, component_name, ...rest);
-};
+export const deprecated =
+  (validator, message = '') =>
+  (props, prop_name, component_name, ...rest) => {
+    warning(
+      isDefined(props[prop_name]),
+      `'${prop_name}' is deprecated on ${component_name}. ${message}`,
+    );
+    return validator(props, prop_name, component_name, ...rest);
+  };
 
 const component = ReactPropTypes.oneOfType([
   ReactPropTypes.func,
@@ -145,6 +142,8 @@ const gmp =
 
 const settings = ReactPropTypes.instanceOf(Settings);
 
+const severityClass = ReactPropTypes.string;
+
 const dateValidator = (props, prop_name, component_name) => {
   const value = props[prop_name];
   if (isDefined(value) && !isDate(value)) {
@@ -258,6 +257,7 @@ const gsaPropTypes = {
   ref,
   set,
   settings,
+  severityClass,
   stringOrFalse,
   timeunit,
   toString,
